@@ -8,7 +8,8 @@ __all__ = ["Error", "DuPanClient", "DuPanShareList"]
 import errno
 
 # from base64 import b64encode
-from collections.abc import deque, Callable, Mapping
+from collections import deque
+from collections.abc import Callable, Iterator, Mapping
 from functools import cached_property, partial
 from itertools import count
 from json import dumps, loads
@@ -308,7 +309,7 @@ class DuPanClient:
             payload = {"fields": dumps(payload, separators=(",", ":"))}
         return self.request(api, params=payload)
 
-    def listdir(
+    def list(
         self, 
         /, 
         payload: str | dict = "/", 
@@ -522,7 +523,7 @@ class DuPanShareList:
         session = self.session = Session()
         session.headers["Referer"] = url
 
-    def __iter__(self, /):
+    def __iter__(self, /) -> Iterator[dict]:
         dq = deque("/")
         get, put = dq.popleft, dq.append
         while dq:
@@ -573,27 +574,27 @@ class DuPanShareList:
 
     @cached_property
     def root(self, /):
-        self.listdir_index()
+        self.list_index()
         return self.__dict__["root"]
 
     @cached_property
     def randsk(self, /) -> str:
-        self.listdir_index()
+        self.list_index()
         return unquote(self.session.cookies.get("BDCLND", ""))
 
     @cached_property
     def share_id(self, /):
-        self.listdir_index()
+        self.list_index()
         return self.__dict__["share_id"]
 
     @cached_property
     def share_uk(self, /):
-        self.listdir_index()
+        self.list_index()
         return self.__dict__["share_uk"]
 
     @cached_property
     def yundata(self, /):
-        self.listdir_index()
+        self.list_index()
         return self.__dict__["yundata"]
 
     def verify(self, /, use_vcode: bool = False):
@@ -615,12 +616,12 @@ class DuPanShareList:
                 else:
                     raise OSError(json)
 
-    def iterdir(self, /, dir="/"):
+    def iterdir(self, /, dir="/") -> Iterator[dict]:
         if dir in ("", "/"):
-            yield from self.listdir_index()
+            yield from self.list_index()
             return
         if not hasattr(self, "share_uk"):
-            self.listdir_index()
+            self.list_index()
         if not dir.startswith("/"):
             dir = self.root + "/" + dir
         api = "https://pan.baidu.com/share/list"
@@ -644,12 +645,12 @@ class DuPanShareList:
                 return
             params["page"] += 1
 
-    def listdir_index(self, /, try_times: int = 5) -> dict:
+    def list_index(self, /, try_times: int = 5) -> list[dict]:
         url = self.url
         password = self.password
         session = self.session
         if try_times <= 0:
-            it = count()
+            it: Iterator[int] = count()
         else:
             it = range(try_times)
         for _ in it:
@@ -685,11 +686,11 @@ class DuPanShareList:
                     return file_list
         raise RuntimeError("too many attempts")
 
-    def listdir(self, dir="/", page=1, num=0):
+    def list(self, dir="/", page=1, num=0) -> list[dict]:
         if dir in ("", "/"):
-            data = self.listdir_index()
+            data = self.list_index()
         if not hasattr(self, "share_uk"):
-            self.listdir_index()
+            self.list_index()
         if not dir.startswith("/"):
             dir = self.root + "/" + dir
         api = "https://pan.baidu.com/share/list"
